sqlmesh.core.snapshot API documentation

Edit on GitHub

# sqlmesh.core.snapshot

View Source

     1from sqlmesh.core.snapshot.categorizer import categorize_change
     2from sqlmesh.core.snapshot.definition import (
     3    Intervals,
     4    QualifiedViewName,
     5    Snapshot,
     6    SnapshotChangeCategory,
     7    SnapshotDataVersion,
     8    SnapshotFingerprint,
     9    SnapshotId,
    10    SnapshotIdLike,
    11    SnapshotInfoLike,
    12    SnapshotNameVersion,
    13    SnapshotNameVersionLike,
    14    SnapshotTableInfo,
    15    fingerprint_from_model,
    16    merge_intervals,
    17    table_name,
    18    to_table_mapping,
    19)
    20from sqlmesh.core.snapshot.evaluator import SnapshotEvaluator